BgBleScannerPlatform class abstract
- Inheritance
-
- Object
- PlatformInterface
- BgBleScannerPlatform
- Implementers
Constructors
- BgBleScannerPlatform()
- Constructs a BgBleScannerPlatform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scanResults
→ Stream<
Map> -
no setter
Methods
-
isBluetoothEnabled(
) → Future< bool> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
startScan(
) → Future< bool> -
stopScan(
) → Future< bool> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ BgBleScannerPlatform
-
The default instance of BgBleScannerPlatform to use.
getter/setter pair